@@ -48,8 +48,10 @@ def maybe_is(x: Any, kinds: List[type]) -> Iterable[bool]:
 
 
 def maybe_(x: Any, kinds: List[type]) -> type:
-    """Return the type of `x` for the first value of which `isinstance` returns true
-    from a list of types in `kinds`.
+    """Return the type of `x` for the first of which equals `kinds`.
+
+    `x` is checked with :func:`isinstance` and the type for which the first one
+    is true is returned.
 
     Example:
         >>> var = "var"
@@ -58,6 +60,7 @@ def maybe_(x: Any, kinds: List[type]) -> type:
 
         >>> maybe_(str, [bool, str, type])
         type
+
     """
     return last_item(first_by(zip(maybe_is(x, kinds), kinds), car))
 
