@@ -1,9 +1,10 @@
-from typing import Union, List, Optional
+from typing import List, Dict, Union, Callable, Optional
 import os
 import sys
 import importlib.machinery
 import importlib.util
 import types
+import argparse
 
 
 class Semver:
@@ -89,3 +90,46 @@ def load_user_module(modname: str, search_path: List[str] = None) -> Optional[ty
     #     return mod
     # else:
     #     return None
+
+
+class hierarchical_parser:
+    def __init__(self, name: str, usage: str, cmd_map: Dict[str, Callable],
+                 version_str: Optional[str] = None):
+        self.name = name
+        self.usage = usage
+        self.cmd_map = cmd_map
+        self.version_str = version_str or "No version provided"
+
+    def __call__(self):
+        parser = argparse.ArgumentParser(self.name, allow_abbrev=False, add_help=False,
+                                         formatter_class=argparse.RawTextHelpFormatter,
+                                         usage=self.usage)
+        parser.add_argument("command", help=f"""Command to run.
+
+command is one of {", ".join(map(lambda x: f'"{x}"', self.cmd_map.keys()))}
+
+Type "{self.name} command --help" to get help about the individual commands.""")
+        if self.version_str:
+            parser.add_argument("--version", action="store_true", help="Print version and exit")
+        if len(sys.argv) == 1:
+            print("No command given\n")
+            parser.print_help()
+            sys.exit(1)
+        elif sys.argv[1] in {"-h", "--help"}:
+            parser.print_help()
+            sys.exit(0)
+        elif sys.argv[1] == "--version" and self.version_str:
+            print(self.version_str)
+            sys.exit(0)
+        try:
+            args, sub_args = parser.parse_known_args()
+        except Exception:
+            parser.print_help()
+            sys.exit(1)
+
+        if args.command in self.cmd_map:
+            self.cmd_map[args.command](sub_args)
+        else:
+            print(f"Unknown command \"{args.command}\"\n")
+            parser.print_help()
+            sys.exit(1)
